@@ -17,10 +17,10 @@ def generate_license(
     https://developer.paddle.com/api-reference/product-api/licenses/createlicense
     """
     url = urljoin(self.vendors_v2, 'product/generate_license')
-    json: PaddleJsonType = {
+    json = {
         'product_id': product_id,
         'allowed_uses': allowed_uses,
-    }
+    }  # type: PaddleJsonType
     if expires_at:
         json['expires_at'] = validate_date(expires_at, 'expires_at')
     return self.post(url=url, json=json)
